Learn R Programming

boussinesq (version 1.0.3)

beq.lin.dimensionless: Analytic exact solution for Dimentionless (i. e. diffusivity equal to 1 - unity) One Dimensional Heat Equation in a two-bounded domain with two constant-value Dirichlet Conditions

Description

Analytic exact solution for Dimentionless (i. e. diffusivity equal to 1 - unity) One Dimensional Heat Equation in a two-bounded domain with two constant-value Dirichlet Conditions

Usage

beq.lin.dimensionless(t = 0, x = seq(from = 0, to = L, by = by), big = 1e+05, by = L * 0.01, L = 1)

Arguments

t
time coordinate.
x
spatial coordinate. Default is seq(from=0,to=L,by=by).
big
maximum level of Fourier series considered. Default is 100000.
by
see seq
L
length of the domain. It is used if x is not specified.

Value

Solutions for the specificied values of x and t

References

Rozier-Cannon, J. (1984), The One-Dimensional Heat Equation, Addison-Wesley Publishing Company, Manlo Park, California, encyclopedia of Mathematics and its applications.

See Also

beq.lin