Rdocumentation
powered by
Learn R Programming
boussinesq (version 1.0.3)
beq.song.dimensionless: Dimensionless solution for one-dimensional derived equation from scaling Boussinesq Equation (Song et al, 2007)
Description
Dimensionless solution for one-dimensional derived equation from scaling Boussinesq Equation (Song et al, 2007)
Usage
beq.song.dimensionless(xi, xi0, a)
Arguments
xi
dimensionless coordinate (see
Note
)
xi0
displacement of wetting front expressed as dimensionless coordinate (see
Note
)
a
vector of coefficient returned by
coefficient.song.solution
Value
the dimesioneless solution, i.e. the variable $H$
References
Song, Zhi-yao;Li, Ling;David, Lockington. (2007), "Note on Barenblatt power series solution to Boussinesq equation",Applied Mathematics and Mechanics,
http://www.springerlink.com/content/w0u8667772712801/
,
http://dx.doi.org/10.1007/s10483-007-0612-x
See Also
beq.song